# MixBytes Tank Change History

## 1.0.1

Fix for GCE provider

Change local terraform priority

## 1.0

Added support of geographically distributed testing, network packet loss

Numerous usability improvements


## 0.2

Added support of test cases

Added support of different blockchains via so-called bindings


## 0.1

Rewritten in Python


## 0.0.1

Initial release
